@@ -3,7 +3,7 @@ Whitelisting HTML scrubber.
 """
 
 __author__ = "Samuel Stauffer <samuel@descolada.com>"
-__version__ = "1.2"
+__version__ = "1.2.1"
 __license__ = "Python"
 
 # 
@@ -212,7 +212,7 @@ class Scrubber(object):
             node.extract()
 
     def _scrub_html_pre(self, html):
-        return html
+        return html.replace(u'\xa0', u' ') # a0 == NBSP
 
     def _scrub_html_post(self, html):
         return html
